@@ -209,6 +209,10 @@ class Univariate:
         return len(self.unique_value_list())
 
     def unique_value_frequency(self):
+        """
+        returns the count of each unique value in a list.
+        :return: unique value count as an int
+        """
         unique_values = self.unique_value_list()
 
         value_count_list = []
@@ -222,9 +226,18 @@ class Univariate:
         return value_count_list
 
     def range(self):
+        """
+        returns the difference between the largest and the smallest value in a list.
+        :return: range returned as a an int
+        """
         return max(self.data) - min(self.data)
 
     def deviation_from_mean_list(self):
+        """
+        returns the difference between the value and the mean for each value in a list. All values below the mean
+        will be negative.
+        :return: deviation from mean as a list
+        """
         mean = self.mean()
         deviation_from_mean_list = []
         for i in sorted(self.data):
@@ -233,6 +246,11 @@ class Univariate:
         return deviation_from_mean_list
 
     def deviation_squared_list(self):
+        """
+        returns the difference between the value and the mean for each value in a list. All values are squared to ensure
+        that their are no negative figures.
+        :return: deviation from mean as a list
+        """
         deviation_squared = []
         for i in self.deviation_from_mean_list():
             deviation_squared.append(i ** 2)
@@ -382,7 +400,7 @@ class Univariate:
         """
         fig2 = plt.figure(constrained_layout=True, figsize=(16, 10))
         mvm = [self.mean(), self.median()]
-        mvm_plot = plt.bar(x=['Mean', 'Mode'], height=mvm)
+        mvm_plot = plt.bar(x=['Mean', 'Median'], height=mvm)
         plt.ylabel('Value')
         plt.title("Mean Vs Median")
 
@@ -570,8 +588,6 @@ class Univariate:
         self.unique_value_distribution()
         plt.show()
         self.violin_plot()
-        print("-----------------")
-
 
 class Bivariate:
     def __init__(self, variable_1, variable_2):
